@@ -5,7 +5,7 @@ use Carp;
 use Data::Dumper;
 use Scalar::Util 'looks_like_number';
 
-our $VERSION = '0.0.3';
+our $VERSION = '0.0.4';
 
 use base qw/Exporter/;
 our @EXPORT = qw (
@@ -615,8 +615,8 @@ you can translate duktape api to perl
     
     $duk->push_c_function(sub { 
         my $duk = shift;
-        my $num1 = shift;
-        my $num2 = shift;
+        my $num1 = $duk->get_int(0);
+        my $num2 = $duk->get_int(1);
 
         my $total = $num1+$num2;
         $duk->push_number($total);
